@@ -41,7 +41,7 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 			manager = SessionManager.getInstance();
 		}
 		catch (NullPointerException e) {
-			_log.error("SessionManager#getInstance null");
+			_log.error("SessionManager#getInstance null returning session expired");
 			return new SessionInfoBean("",""); //tells session expired
 		}
 		if (manager == null) {
@@ -56,13 +56,18 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 			if (session == null || session.getUsername() == null) {
 				UserLocalServiceUtil.getService();
 				_log.warn("Liferay Portal Detected but session Expired");
-				return new SessionInfoBean("",""); //tells session expired
+				return new SessionInfoBean(null,null); //tells session expired
 			}
 		}
 		catch (Exception e) {
-			_log.warn("Stopping session polling as you are in dev mode (am I wrong?)");
-			e.printStackTrace();
-			return new SessionInfoBean("","", true); //tells that you are in development mode 
+			if (isWithinPortal()) {
+				_log.warn("Liferay Portal Detected but session Expired");
+				return new SessionInfoBean(null,null); //tells session expired
+			}
+			else {
+				_log.warn("Stopping session polling as i think you are in development mode");
+				return new SessionInfoBean("","", true); //tells that you are in development mode 				
+			}
 		}	
 		String user = session.getUsername();
 		String scope = session.getScope();
@@ -77,4 +82,18 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 		return new SessionInfoBean(session.getUsername(), session.getScope());
 	}
 
+	/**
+	 * 
+	 * @return true if you're running into the portal, false if in development
+	 */
+	private boolean isWithinPortal() {
+		try {
+			UserLocalServiceUtil.getService();
+			return true;
+		} 
+		catch (com.liferay.portal.kernel.bean.BeanLocatorException ex) {			
+			_log.trace("Development Mode ON");
+			return false;
+		}			
+	}
 }
